"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
const utils_1 = require("@umijs/utils");
const dev_1 = require("umi/dist/cli/dev");
const node_1 = require("umi/dist/cli/node");
const constants_1 = require("umi/dist/constants");
const service_1 = require("umi/dist/service/service");
async function run(opts = {}) {
    (0, node_1.checkVersion)();
    (0, node_1.checkLocal)();
    const args = (0, utils_1.yParser)(process.argv.slice(2), {
        alias: {
            version: ['v'],
            help: ['h'],
        },
        boolean: ['version'],
    });
    const command = args._[0];
    if ([constants_1.DEV_COMMAND, 'setup'].includes(command)) {
        process.env.NODE_ENV = 'development';
    }
    else if (command === 'build') {
        process.env.NODE_ENV = 'production';
    }
    opts.presets = opts?.presets
        ? opts?.presets.concat([require.resolve('./preset')])
        : [require.resolve('./preset')];
    if (opts?.presets) {
        process.env.UMI_PRESETS = opts.presets.join(',');
    }
    if (!opts.defaultConfigFiles && command === constants_1.DEV_COMMAND) {
        (0, dev_1.dev)();
    }
    else if (command === 'version' || command === 'v') {
        const version = require('../package.json').version;
        console.log(`alita@${version}`);
    }
    else {
        try {
            await new service_1.Service({
                defaultConfigFiles: opts.defaultConfigFiles || null,
            }).run2({
                name: args._[0],
                args,
            });
        }
        catch (e) {
            utils_1.logger.error(e);
            process.exit(1);
        }
    }
}
exports.run = run;
